@@ -30,7 +30,7 @@
 #include <QHash>
 
 class AbstractCollectionMigrator;
-class ImapCacheLocalImporter;
+class ImapCacheAdapter;
 class KJob;
 class MixedMaildirStore;
 class OrgKdeAkonadiImapSettingsInterface;
@@ -63,6 +63,7 @@ class KMailMigrator : public KMigratorBase
     void migrateLocalFolders();
     void migrationDone();
     void deleteOldGroup();
+    void migrateConfigurationDialogRestriction();
 
   Q_SIGNALS:
     void status( const QString &msg );
@@ -87,12 +88,17 @@ class KMailMigrator : public KMigratorBase
     void instanceStatusChanged( const Akonadi::AgentInstance &instance );
     void instanceProgressChanged( const Akonadi::AgentInstance &instance );
 
+#if 0
     void imapCacheImportFinished( const Akonadi::AgentInstance &instance, const QString &error );
     void imapCacheCleanupFinished( const Akonadi::AgentInstance &instance );
+#endif
+    void imapCacheAdaptionFinished( int messageType, const QString &message );
 
     void specialColDefaultResourceCheckFinished( const Akonadi::AgentInstance &instance );
 
-    private:
+    void autoSaveCopyResult( KJob* );
+
+  private:
     void deleteOldGroup( const QString& );
     void migrateImapAccount( KJob *job, bool disconnected );
     bool migrateCurrentAccount();
@@ -108,7 +114,6 @@ class KMailMigrator : public KMigratorBase
 
     void connectCollectionMigrator( AbstractCollectionMigrator *migrator );
 
-    bool evaluateCacheHandlingOptions();
     void migrateInstanceTrashFolder();
 
     void migratePassword( const QString &idString, const Akonadi::AgentInstance &instance,
@@ -133,23 +138,21 @@ class KMailMigrator : public KMigratorBase
     typedef QStringList::iterator AccountIterator;
     AccountIterator mIt;
     Akonadi::AgentInstance mCurrentInstance;
-    bool mDeleteCacheAfterImport;
     MixedMaildirStore *mDImapCache;
     MixedMaildirStore *mImapCache;
-    int mRunningCacheImporterCount;
-    bool mLocalFoldersDone;
 
     struct AccountConfig {
-      AccountConfig() : imapAccount( false ){ }
+      AccountConfig() : imapAccount( false ), disconnectedImap( false ) { }
       Akonadi::AgentInstance instance;
       bool imapAccount;
+      bool disconnectedImap;
     };
     QHash<QString, AccountConfig> mAccountInstance;
     QList<Akonadi::AgentInstance> mFailedInstances;
 
     bool mForwardResourceNotifications;
 
-    ImapCacheLocalImporter *mLocalCacheImporter;
+    ImapCacheAdapter *mImapCacheAdapter;
 };
 
 } // namespace KMail
