@@ -113,6 +113,12 @@ void DavGroupwareResource::collectionRemoved( const Akonadi::Collection &collect
   job->start();
 }
 
+void DavGroupwareResource::cleanup()
+{
+  Settings::self()->cleanup();
+  Akonadi::AgentBase::cleanup();
+}
+
 void DavGroupwareResource::configure( WId windowId )
 {
   Settings::self()->setWinId( windowId );
@@ -133,6 +139,7 @@ void DavGroupwareResource::configure( WId windowId )
         urlConfig->mUrl = url.url;
         urlConfig->mProtocol = url.protocol;
         urlConfig->mUser = url.userName;
+        urlConfig->mPassword = wizard.field( "credentialsPassword" ).toString();
 
         Settings::self()->newUrlConfiguration( urlConfig );
       }
