@@ -49,6 +49,7 @@ class Settings : public SettingsBase
         QString serialize();
         QString mUrl;
         QString mUser;
+        QString mPassword;
         int mProtocol;
     };
 
@@ -56,6 +57,7 @@ class Settings : public SettingsBase
     virtual ~Settings();
     static Settings* self();
     void setWinId( WId wid );
+    void cleanup();
 
     DavUtils::DavUrl::List configuredDavUrls();
 
@@ -86,12 +88,17 @@ class Settings : public SettingsBase
 
     //DavUtils::Protocol protocol( const QString &url ) const;
     QString username( DavUtils::Protocol protocol, const QString &url ) const;
+    QString password( DavUtils::Protocol protocol, const QString &url );
 
   private:
+    void loadMappings();
     void updateRemoteUrls();
+    void savePassword( const QString &key, const QString &user, const QString &password );
+    QString loadPassword( const QString &key, const QString &user );
 
     WId mWinId;
     QMap<QString, UrlConfiguration*> mUrls;
+    QString mCollectionsUrlsMappingCache;
     QMap<QString, QString> mCollectionsUrlsMapping;
     QList<UrlConfiguration*> mToDeleteUrlConfigs;
 };
