@@ -313,8 +313,12 @@ CredentialsPage::CredentialsPage( QWidget *parent )
 
   mUserName = new KLineEdit;
   layout->addRow( i18n( "User" ), mUserName );
-
   registerField( "credentialsUserName*", mUserName );
+
+  mPassword = new KLineEdit;
+  mPassword->setPasswordMode( true );
+  layout->addRow( i18n( "Password" ), mPassword );
+  registerField( "credentialsPassword*", mPassword );
 }
 
 CheckPage::CheckPage( QWidget *parent )
@@ -348,6 +352,7 @@ void CheckPage::checkConnection()
 
     KUrl serverUrl( url.url );
     serverUrl.setUser( url.userName );
+    serverUrl.setPass( wizard()->field( "credentialsPassword" ).toString() );
     davUrl.setUrl( serverUrl );
 
     davUrls << davUrl;
