@@ -33,6 +33,8 @@
 #include <kimap/session.h>
 #include <kimap/sessionuiproxy.h>
 
+#include <kpimutils/networkaccesshelper.h>
+
 #include "imapaccount.h"
 #include "passwordrequesterinterface.h"
 
@@ -44,7 +46,8 @@ SessionPool::SessionPool( int maxPoolSize, QObject *parent)
     m_account( 0 ),
     m_passwordRequester( 0 ),
     m_initialConnectDone( false ),
-    m_pendingInitialSession( 0 )
+    m_pendingInitialSession( 0 ),
+    m_networkAccessHelper( new KPIMUtils::NetworkAccessHelper( this ) )
 {
 }
 
@@ -78,12 +81,19 @@ void SessionPool::setSessionUiProxy( KIMAP::SessionUiProxy::Ptr proxy )
   m_sessionUiProxy = proxy;
 }
 
+bool SessionPool::isConnected() const
+{
+  return m_initialConnectDone;
+}
+
 bool SessionPool::connect( ImapAccount *account )
 {
   if ( m_account ) {
     return false;
   }
 
+  m_networkAccessHelper->establishConnection();
+
   m_account = account;
   if ( m_account->authenticationMode() == KIMAP::LoginJob::GSSAPI ) {
     // for GSSAPI we don't have to ask for username/password, because it uses session wide tickets
@@ -97,14 +107,16 @@ bool SessionPool::connect( ImapAccount *account )
   return true;
 }
 
-void SessionPool::disconnect()
+void SessionPool::disconnect( SessionTermination termination )
 {
   if ( !m_account ) {
     return;
   }
 
+  m_networkAccessHelper->releaseConnection();
+
   foreach ( KIMAP::Session *s, m_idlePool+m_reservedPool ) {
-    killSession( s );
+    killSession( s, termination );
   }
   m_idlePool.clear();
   m_reservedPool.clear();
@@ -115,6 +127,7 @@ void SessionPool::disconnect()
   m_capabilities.clear();
 
   m_initialConnectDone = false;
+  emit disconnectDone();
 }
 
 qint64 SessionPool::requestSession()
@@ -137,11 +150,10 @@ qint64 SessionPool::requestSession()
 
 void SessionPool::releaseSession( KIMAP::Session *session )
 {
-  Q_ASSERT( m_initialConnectDone );
-  Q_ASSERT( m_reservedPool.contains( session ) );
-
-  m_reservedPool.removeAll( session );
-  m_idlePool << session;
+  if ( m_reservedPool.contains( session ) ) {
+    m_reservedPool.removeAll( session );
+    m_idlePool << session;
+  }
 }
 
 ImapAccount *SessionPool::account() const
@@ -159,21 +171,30 @@ QList<KIMAP::MailBoxDescriptor> SessionPool::serverNamespaces() const
   return m_namespaces;
 }
 
-void SessionPool::killSession( KIMAP::Session *session )
+void SessionPool::killSession( KIMAP::Session *session, SessionTermination termination )
 {
+  QObject::disconnect( session, SIGNAL(connectionLost()),
+                       this, SLOT(onEarlyConnectionLost()) );
   QObject::disconnect( session, SIGNAL(connectionLost()),
                        this, SLOT(onConnectionLost()) );
 
-  KIMAP::LogoutJob *logout = new KIMAP::LogoutJob( session );
-  QObject::connect( logout, SIGNAL( result( KJob* ) ),
-                    session, SLOT( deleteLater() ) );
-  logout->start();
+  if ( session->state() != KIMAP::Session::Disconnected && termination == LogoutSession ) {
+    KIMAP::LogoutJob *logout = new KIMAP::LogoutJob( session );
+    QObject::connect( logout, SIGNAL( result( KJob* ) ),
+                      session, SLOT( deleteLater() ) );
+    logout->start();
+  } else {
+    session->close();
+    session->deleteLater();
+  }
 }
 
 void SessionPool::declareSessionReady( KIMAP::Session *session )
 {
   m_pendingInitialSession = 0;
 
+  QObject::disconnect( session, SIGNAL(connectionLost()),
+                       this, SLOT(onEarlyConnectionLost()) );
   QObject::connect( session, SIGNAL(connectionLost()),
                     this, SLOT(onConnectionLost()) );
 
@@ -195,14 +216,14 @@ void SessionPool::cancelSessionCreation( KIMAP::Session *session, int errorCode,
   m_pendingInitialSession = 0;
 
   if ( !m_initialConnectDone ) {
-    emit connectDone( errorCode,
-                      i18n( "Could not connect to the IMAP-server %1.\n%2",
-                            m_account->server(),
-                            errorMessage ) );
+    if ( m_account )
+      emit connectDone( errorCode, i18n( "Could not connect to the IMAP-server %1.\n%2", m_account->server(), errorMessage ) );
+    else // this case can happen when we loose all ready connections while trying to establish a new one for example
+      emit connectDone( errorCode, i18n( "Cound not connect to the IMAP server.\n%1", errorMessage ) );
     disconnect();
-    killSession( session );
+    killSession( session, LogoutSession );
   } else {
-    killSession( session );
+    killSession( session, LogoutSession );
     emit sessionRequestDone( m_pendingRequests.takeFirst(), 0, errorCode, errorMessage );
     if ( !m_pendingRequests.isEmpty() ) {
       QTimer::singleShot( 0, this, SLOT(processPendingRequests()) );
@@ -242,6 +263,16 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
 {
   QString errorMessage;
 
+  if ( !m_account ) {
+    // it looks like the connection was lost while we were waiting
+    // for the password, we should fail all the pending requests and stop there
+    foreach ( int request, m_pendingRequests ) {
+      emit sessionRequestDone( request, 0,
+                               LoginFailError, i18n( "Disconnected from server during login." ) );
+    }
+    return;
+  }
+
   switch ( resultType )
   {
   case PasswordRequesterInterface::PasswordRetrieved:
@@ -285,7 +316,9 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
   } else {
     session = new KIMAP::Session( m_account->server(), m_account->port(), this );
     session->setUiProxy( m_sessionUiProxy );
+    session->setTimeout( m_account->timeout() );
   }
+  QObject::connect( session, SIGNAL(connectionLost()), this, SLOT(onEarlyConnectionLost()) );
 
   KIMAP::LoginJob *loginJob = new KIMAP::LoginJob( session );
   loginJob->setUserName( m_account->userName() );
@@ -298,6 +331,14 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
   loginJob->start();
 }
 
+void SessionPool::onEarlyConnectionLost()
+{
+  kDebug() << sender();
+  KIMAP::Session *session = qobject_cast<KIMAP::Session*>( sender() );
+  Q_ASSERT( session );
+  cancelSessionCreation( session, LoginFailError, i18n( "Failed to connect to server" ) );
+}
+
 void SessionPool::onLoginDone( KJob *job )
 {
   KIMAP::LoginJob *login = static_cast<KIMAP::LoginJob*>( job );
@@ -342,14 +383,6 @@ void SessionPool::onCapabilitiesTestDone( KJob *job )
   QStringList expected;
   expected << "IMAP4REV1";
 
-  // Both GMail and GMX servers seem to be lying about their capabilities
-  // They don't report UIDPLUS correctly so don't check for it explicitly
-  // if it's one of those servers.
-  if ( !m_capabilities.contains( "X-GM-EXT-1" )
-    && !capJob->session()->serverGreeting().contains( "GMX" ) ) {
-    expected << "UIDPLUS";
-  }
-
   QStringList missing;
 
   foreach ( const QString &capability, expected ) {
@@ -409,11 +442,18 @@ void SessionPool::onConnectionLost()
   m_idlePool.removeAll( session );
   m_reservedPool.removeAll( session );
 
+  if ( m_idlePool.isEmpty() && m_reservedPool.isEmpty() ) {
+    delete m_account;
+    m_account = 0;
+    m_namespaces.clear();
+    m_capabilities.clear();
+
+    m_initialConnectDone = false;
+  }
+
   emit connectionLost( session );
 
   session->deleteLater();
 }
 
 #include "sessionpool.moc"
-
-
