@@ -21,27 +21,33 @@
 #include "calendarhandler.h"
 #include "taskshandler.h"
 #include "journalhandler.h"
+#include "notehandler.h"
+
+#include <KCalCore/Event>
+#include <KCalCore/Todo>
+#include <KCalCore/Journal>
 
-#include <akonadi/collection.h>
-#include <akonadi/kcal/incidencemimetypevisitor.h>
 #include <kabc/addressee.h>
+#include <kabc/contactgroup.h>
 
-KolabHandler::KolabHandler()
+
+KolabHandler::KolabHandler( const Akonadi::Collection &imapCollection ) : m_imapCollection( imapCollection )
 {
 }
 
-KolabHandler *KolabHandler::createHandler(const QByteArray& type)
+KolabHandler *KolabHandler::createHandler( const QByteArray& type,
+                                           const Akonadi::Collection &imapCollection )
 {
   if (type ==  "contact.default" || type ==  "contact") {
-    return new AddressBookHandler();
+    return new AddressBookHandler( imapCollection );
   } else if (type ==  "event.default" || type ==  "event") {
-    return new CalendarHandler();
+    return new CalendarHandler( imapCollection );
   } else if (type ==  "task.default" || type ==  "task") {
-    return new TasksHandler();
+    return new TasksHandler( imapCollection );
   } else if (type ==  "journal.default" || type ==  "journal") {
-    return new JournalHandler();
+    return new JournalHandler( imapCollection );
   } else if (type ==  "note.default" || type ==  "note") {
-    return new NotesHandler();
+    return new NotesHandler( imapCollection );
   } else {
     return 0;
   }
@@ -53,18 +59,29 @@ QByteArray KolabHandler::kolabTypeForCollection(const Akonadi::Collection& colle
   const QStringList contentMimeTypes = collection.contentMimeTypes();
   if ( contentMimeTypes.contains( KABC::Addressee::mimeType() ) ) {
     return "contact";
-  } else if ( contentMimeTypes.contains( Akonadi::IncidenceMimeTypeVisitor::eventMimeType() ) ) {
+  } else if ( contentMimeTypes.contains( KCalCore::Event::eventMimeType() ) ) {
     return "event";
-  } else if ( contentMimeTypes.contains( Akonadi::IncidenceMimeTypeVisitor::todoMimeType() ) ) {
+  } else if ( contentMimeTypes.contains( KCalCore::Todo::todoMimeType() ) ) {
     return "task";
-  } else if ( contentMimeTypes.contains( Akonadi::IncidenceMimeTypeVisitor::journalMimeType() ) ) {
+  } else if ( contentMimeTypes.contains( KCalCore::Journal::journalMimeType() ) ) {
     return "journal";
-  } else if ( contentMimeTypes.contains( "application/x-vnd.akonadi.notes" ) ) {
+  } else if ( contentMimeTypes.contains( "application/x-vnd.akonadi.note" ) || contentMimeTypes.contains( "text/x-vnd.akonadi.note" ) ) {
     return "note";
   }
   return QByteArray();
 }
 
+QStringList KolabHandler::allSupportedMimeTypes()
+{
+  return QStringList()
+   << KABC::Addressee::mimeType()
+   << KABC::ContactGroup::mimeType()
+   << KCalCore::Event::eventMimeType()
+   << KCalCore::Todo::todoMimeType()
+   << KCalCore::Journal::journalMimeType()
+   << QLatin1String( "application/x-vnd.akonadi.note" )
+   << QLatin1String( "text/x-vnd.akonadi.note" );
+}
 
 
 KolabHandler::~KolabHandler()
