@@ -25,7 +25,7 @@
 class NotesHandler : public JournalHandler
 {
   public:
-    NotesHandler();
+    explicit NotesHandler( const Akonadi::Collection &imapCollection );
 
     virtual Akonadi::Item::List translateItems(const Akonadi::Item::List & kolabItems);
     virtual void toKolabFormat(const Akonadi::Item& item, Akonadi::Item &imapItem);
