@@ -47,8 +47,7 @@ POP3Resource::POP3Resource( const QString &id )
       mAskAgain( false ),
       mIntervalTimer( new QTimer( this ) ),
       mTestLocalInbox( false ),
-      mWallet( 0 ),
-      mErrorDialogShown( false )
+      mWallet( 0 )
 {
   setNeedsNetwork( true );
   Settings::self()->setResourceId( identifier() );
@@ -85,7 +84,7 @@ void POP3Resource::updateIntervalTimer()
 void POP3Resource::intervalCheckTriggered()
 {
   Q_ASSERT( mState == Idle );
-  if ( isOnline() && !mErrorDialogShown ) {
+  if ( isOnline() ) {
     kDebug() << "Starting interval mail check.";
     startMailCheck();
     mIntervalCheckInProgress = true;
@@ -520,23 +519,6 @@ void POP3Resource::loginJobResult( KJob *job )
       mAskAgain = true;
     cancelSync( i18n( "Unable to login to the server %1.", Settings::self()->host() ) +
                 '\n' + job->errorString() );
-
-    // FIXME: "The server refused the supplied username and password." is not correct! The server might
-    //        not even be online, there might be a connection problem etc
-    mErrorDialogShown = true;
-    int i = KMessageBox::questionYesNoCancelWId( winIdForDialogs(),
-                                  i18n( "The server refused the supplied username and password. "
-                                        "Do you want to go to the settings, have another attempt "
-                                        "at logging in, or do nothing?\n\n"
-                                        "%1", job->errorString() ),
-                                  i18n( "Could Not Authenticate" ),
-                                  KGuiItem( i18n( "Settings" ) ),
-                                  KGuiItem( i18nc( "Input username/password manually and not store them", "Single Input" ) ) );
-    mErrorDialogShown = false;
-    if ( i == KMessageBox::Yes ) {
-      configure( winIdForDialogs() );
-      return;
-    }
   }
   else {
     advanceState( List );
@@ -998,7 +980,7 @@ void POP3Resource::startMailCheck()
 
 void POP3Resource::retrieveCollections()
 {
-  if ( mState == Idle && !mErrorDialogShown ) {
+  if ( mState == Idle ) {
     startMailCheck();
   }
   else {
